@@ -168,6 +168,10 @@ class ONTMIGRATION(Base):
     subs_id = Column(String(length=64), comment='Billing system Subscription ID')
     old_ont_register_datetime = Column(DateTime)
     old_service_provision_datetime = Column(DateTime)
+    ont_svc_port_deleted = Column(Boolean, default=False)
+    ont_svc_port_deleted_datetime = Column(DateTime)
+    ont_deleted_from_olt = Column(Boolean, default=False)
+    ont_deleted_from_olt_datetime = Column(DateTime)
     ont_expunged = Column(Boolean, default=False)
     ont_expunge_datetime = Column(DateTime)
     new_db_record_required = Column(Boolean, default=False, comment='If DB records are required to be created')
